# reticulok
A package to get repititions on DevOps best practices, python library deployment, and coding challenge solutions.

## Overview
As a professional data engineer, I've noticed that my everyday responsibilities fall into four main buckets:

* **A - Ingestion of Data from External Sources**
* **B - Processing of Data via Optimized Code**
* **C - Structuring Data into Marts for Downstream Ingestion/Analysis**
* **D - Infrastructural and DevOps to Automate Deployment/Testing**
